============
Useful links
============

Tom's Youtube Channel
+++++++++++++++++++++

An example of using Django Tenants and other Python / Django related video `Click Here <https://www.youtube.com/channel/UCUKoRhPhS0INxh6RC1xN_TQ>`_

SaaSy maps
++++++++++
SaaSy maps - using django-tenants and geodjango to provide web-gis software-as-a-service `http://www.slideshare.net/AnushaChickermane/saasy-maps <http://www.slideshare.net/AnushaChickermane/saasy-maps>`_


django-tenant-users
+++++++++++++++++++
An application expands the django users and permissions frameworks `https://github.com/Corvia/django-tenant-users <https://github.com/Corvia/django-tenant-users>`_
